@@ -35,7 +35,10 @@ kickoff.writeConfig("showAppsByName", "true")
 
 //panel.addWidget("org.kde.plasma.showActivityManager")
 panel.addWidget("org.kde.plasma.pager")
-panel.addWidget("org.kde.plasma.taskmanager")
+
+var taskmanager = panel.addWidget("org.kde.plasma.taskmanager")
+var launcherlist = [ ]
+taskmanager.writeConfig("launchers", launcherlist)
 
 /* Next up is determining whether to add the Input Method Panel
  * widget to the panel or not. This is done based on whether
